Code in this directory comes from the [`OpenNMT` library](https://github.com/OpenNMT/OpenNMT-py) (v3.5.1).

As we need to modify the internals of the functions and classes included, we directly copy the relevant code
instead of adding it as a formal dependency.
